@@ -6,8 +6,11 @@ from .archive_factory import *
 from .comparators import *
 from .depositors import *
 from .exceptions import *  # pylint: disable=redefined-builtin
+from .expr import *
+from .fields import *
 from .helpers import *
 from .historians import *
+from .hist import *
 from .history import *
 from .migrations import *
 from .process import *
@@ -18,15 +21,17 @@ from .types import *
 from .version import *
 from . import builtins
 from . import common_helpers
-from . import history
+from . import history  # pylint: disable=cyclic-import
 from . import mongo
 from . import operations
 from . import process
+from . import testing
 from . import utils
 
-_ADDITIONAL = 'mongo', 'builtins', 'common_helpers', 'utils', 'q', 'operations'
+_ADDITIONAL = 'mongo', 'builtins', 'common_helpers', 'utils', 'q', 'operations', 'testing'
 
 __all__ = (archives.__all__ + depositors.__all__ + exceptions.__all__ + historians.__all__ +
            process.__all__ + types.__all__ + helpers.__all__ + version.__all__ + history.__all__ +
            archive_factory.__all__ + refs.__all__ + records.__all__ + base_savable.__all__ +
-           builtins.__all__ + migrations.__all__ + tracking.__all__ + _ADDITIONAL)
+           builtins.__all__ + migrations.__all__ + tracking.__all__ + hist.__all__ +
+           fields.__all__ + expr.__all__ + _ADDITIONAL)
