@@ -1,15 +1,20 @@
+"""
+This module exposes some global functionality for connecting to and interacting with the current
+historian
+"""
 import os
 from typing import Optional
 
 import deprecation
 
 from . import archive_factory
+from . import helpers
 from . import historians
 from . import plugins
 from . import version
 
 __all__ = ('connect', 'get_historian', 'set_historian', 'DEFAULT_ARCHIVE_URI', 'ENV_ARCHIVE_URI', \
-           'archive_uri', 'load', 'save')
+           'archive_uri', 'load', 'save', 'default_archive_uri', 'find', 'delete', 'db')
 
 DEFAULT_ARCHIVE_URI = 'mongodb://localhost/mincepy'
 ENV_ARCHIVE_URI = 'MINCEPY_ARCHIVE'
@@ -66,7 +71,8 @@ def get_historian(create=True) -> Optional[historians.Historian]:
     call will attempt to create a new default historian using connect()"""
     global CURRENT_HISTORIAN  # pylint: disable=global-statement
     if CURRENT_HISTORIAN is None and create:
-        # Try creating a new one
+        # Try creating a new one, use globally otherwise a new one will be created each time which
+        # is unlikely to be what users want
         connect(use_globally=True)
 
     return CURRENT_HISTORIAN
@@ -88,8 +94,23 @@ def load(*obj_ids_or_refs):
 
 
 def save(*objs):
-    """Save one or more objects using the current global historian"""
+    """Save one or more objects.  See :py:meth:`mincepy.Historian.save`"""
     return get_historian().save(*objs)
 
 
+def find(*args, **kwargs):
+    """Find objects.  See :py:meth:`mincepy.Historian.find`"""
+    yield from get_historian().find(*args, **kwargs)
+
+
+def delete(*obj_or_identifier):
+    """Delete an object.  See :py:meth:`mincepy.Historian.delete`"""
+    return get_historian().delete(*obj_or_identifier)
+
+
+def db(type_id_or_type) -> helpers.TypeHelper:  # pylint: disable=invalid-name
+    """Get the database type helper for a type.  See :py:meth:`mincepy.Historian.get_helper`"""
+    return get_historian().get_helper(type_id_or_type)
+
+
 # endregion
