@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 from typing import Optional, Sequence, Union, Iterable, Mapping, Iterator, Dict, Tuple
 import uuid
 
@@ -11,6 +12,7 @@ import pymongo.errors
 
 import mincepy
 import mincepy.records
+from mincepy import archives
 from mincepy import operations
 from mincepy import q
 from mincepy import exceptions
@@ -18,7 +20,6 @@ from mincepy import exceptions
 from . import bulk
 from . import migrate
 from . import migrations
-from . import files
 from . import db
 from . import references
 from . import queries
@@ -27,7 +28,7 @@ __all__ = ('MongoArchive', 'connect')
 
 DEFAULT_REFERENCES_COLLECTION = 'references'
 
-scalar_query_spec = mincepy.archives.scalar_query_spec  # pylint: disable=invalid-name
+scalar_query_spec = mincepy.archives.scalar_query_spec
 
 
 class ObjectIdHelper(mincepy.TypeHelper):
@@ -61,7 +62,7 @@ class MongoArchive(mincepy.BaseArchive[bson.ObjectId]):
 
     @classmethod
     def get_types(cls) -> Sequence:
-        return ObjectIdHelper(), files.GridFsFile
+        return (ObjectIdHelper(),)
 
     def __init__(self, database: pymongo.database.Database):
         self._database = database
@@ -73,6 +74,12 @@ class MongoArchive(mincepy.BaseArchive[bson.ObjectId]):
         self._file_bucket = gridfs.GridFSBucket(database)
         self._refman = references.ReferenceManager(database[DEFAULT_REFERENCES_COLLECTION],
                                                    self._data_collection, self._history_collection)
+
+        self._snapshots = MongoRecordCollection(self, self._history_collection,
+                                                self._meta_collection.name)
+        self._objects = MongoRecordCollection(self, self._data_collection,
+                                              self._meta_collection.name)
+
         self._create_indices()
 
     @property
@@ -83,6 +90,19 @@ class MongoArchive(mincepy.BaseArchive[bson.ObjectId]):
     def data_collection(self) -> pymongo.database.Collection:
         return self._data_collection
 
+    @property
+    def snapshots(self) -> 'MongoRecordCollection':
+        return self._snapshots
+
+    @property
+    def objects(self) -> 'MongoRecordCollection':
+        """Access the objects collection"""
+        return self._objects
+
+    @property
+    def file_store(self) -> gridfs.GridFSBucket:
+        return self._file_bucket
+
     def _create_indices(self):
         # Create all the necessary indexes
         self._data_collection.create_index(db.OBJ_ID)
@@ -91,6 +111,7 @@ class MongoArchive(mincepy.BaseArchive[bson.ObjectId]):
                                               unique=True)
         # Performance related
         self._data_collection.create_index(db.TYPE_ID, unique=False)
+        self._data_collection.create_index(db.VERSION, unique=False)
 
     def create_archive_id(self):  # pylint: disable=no-self-use
         return bson.ObjectId()
@@ -101,10 +122,7 @@ class MongoArchive(mincepy.BaseArchive[bson.ObjectId]):
         try:
             return bson.ObjectId(value)
         except bson.errors.InvalidId as exc:
-            raise ValueError(str(exc))
-
-    def create_file(self, filename: str = None, encoding: str = None):
-        return files.GridFsFile(self._file_bucket, filename, encoding)
+            raise ValueError(str(exc)) from None
 
     def get_gridfs_bucket(self) -> gridfs.GridFSBucket:
         return self._file_bucket
@@ -116,8 +134,8 @@ class MongoArchive(mincepy.BaseArchive[bson.ObjectId]):
         history_ops = []
 
         for data_op, history_op in map(bulk.to_mongo_op, ops):
-            data_ops.append(data_op)
-            history_ops.append(history_op)
+            data_ops.extend(data_op)
+            history_ops.extend(history_op)
 
         try:
             # First perform the data operations
@@ -164,7 +182,7 @@ class MongoArchive(mincepy.BaseArchive[bson.ObjectId]):
     def meta_get(self, obj_id: Union[bson.ObjectId, Iterable[bson.ObjectId]]):
         # Single obj id
         if not isinstance(obj_id, bson.ObjectId):
-            raise TypeError("Must pass an ObjectId, got {}".format(obj_id))
+            raise TypeError('Must pass an ObjectId, got {}'.format(obj_id))
         found = self._meta_collection.find_one({'_id': obj_id})
         if found is None:
             return found
@@ -175,7 +193,7 @@ class MongoArchive(mincepy.BaseArchive[bson.ObjectId]):
         # Find multiple
         for obj_id in obj_ids:
             if not isinstance(obj_id, bson.ObjectId):
-                raise TypeError("Must pass an ObjectId, got {}".format(obj_id))
+                raise TypeError('Must pass an ObjectId, got {}'.format(obj_id))
 
         cur = self._meta_collection.find({'_id': q.in_(*obj_ids)})
         results = {oid: None for oid in obj_ids}
@@ -222,14 +240,13 @@ class MongoArchive(mincepy.BaseArchive[bson.ObjectId]):
 
     def meta_update(self, obj_id, meta: Mapping):
         if meta.get('_id', obj_id) != obj_id:
-            raise ValueError("Cannot use the key _id, in metadata: it is reserved")
+            raise ValueError('Cannot use the key _id, in metadata: it is reserved')
 
         try:
             self._meta_collection.update_one({'_id': obj_id}, {'$set': meta}, upsert=True)
         except pymongo.errors.DuplicateKeyError as exc:
             raise mincepy.DuplicateKeyError(str(exc))
 
-    # pylint: disable=bad-continuation
     def meta_find(
         self,
         filter: dict = None,  # pylint: disable=redefined-builtin
@@ -258,7 +275,7 @@ class MongoArchive(mincepy.BaseArchive[bson.ObjectId]):
     def meta_create_index(self, keys, unique=True, where_exist=False):
         kwargs = {}
         if where_exist:
-            if not isinstance(keys, str) and isinstance(keys, Iterable):
+            if not isinstance(keys, str) and isinstance(keys, Iterable):  # pylint: disable=isinstance-second-argument-not-valid-type
                 key_names = tuple(entry[0] for entry in keys)
             else:
                 key_names = (keys,)
@@ -318,6 +335,12 @@ class MongoArchive(mincepy.BaseArchive[bson.ObjectId]):
         for result in results:
             yield db.to_record(result)
 
+    def find_exp(self, records_filter: dict):
+        """Experimental find"""
+        results = self._data_collection.find(records_filter)
+        for result in results:
+            yield db.to_record(result)
+
     def distinct(self, key: str, filter: dict = None) -> Iterator:  # pylint: disable=redefined-builtin
         filter = db.remap(filter)
 
@@ -327,7 +350,7 @@ class MongoArchive(mincepy.BaseArchive[bson.ObjectId]):
         else:
             coll = self._history_collection
 
-        yield from coll.distinct(db.remap_key(key), filter=_flatten_filter_dict(filter))
+        yield from coll.distinct(db.remap_key(key), expression=_flatten_filter_dict(filter))
 
     def count(self,
               obj_id: Optional[bson.ObjectId] = None,
@@ -361,7 +384,7 @@ class MongoArchive(mincepy.BaseArchive[bson.ObjectId]):
         if limit:
             pipeline.append({'$limit': limit})
 
-        pipeline.append({'$count': "total"})
+        pipeline.append({'$count': 'total'})
         result = next(coll.aggregate(pipeline))
 
         return result['total']
@@ -464,12 +487,104 @@ def _flatten_filter_dict(filter: dict) -> dict:  # pylint: disable=redefined-bui
     return query.build()
 
 
+class MongoRecordCollection(archives.RecordCollection):
+
+    def __init__(self, archive: MongoArchive, collection: pymongo.database.Collection,
+                 meta_collection_name: str):
+        self._archive = archive
+        self._collection = collection
+        self._meta_collection_name = meta_collection_name
+
+    @property
+    def archive(self) -> MongoArchive:
+        """Get the corresponding archive"""
+        return self._archive
+
+    def find(
+            self,
+            filter: dict,  # pylint: disable=redefined-builtin
+            *,
+            projection=None,
+            meta: dict = None,
+            limit=0,
+            sort=None,
+            skip=0) -> Iterator[dict]:
+
+        # Create the pipeline
+        pipeline = []
+
+        if filter:
+            pipeline.append({'$match': filter})
+
+        if meta:
+            pipeline.extend(
+                queries.pipeline_match_metadata(meta, self._meta_collection_name, db.OBJ_ID))
+
+        if sort:
+            if not isinstance(sort, dict):
+                sort_dict = {sort: 1}
+            else:
+                sort_dict = sort
+            sort_dict = db.remap(sort_dict)
+            pipeline.append({'$sort': sort_dict})
+
+        if skip:
+            pipeline.append({'$skip': skip})
+
+        if limit:
+            pipeline.append({'$limit': limit})
+
+        if projection:
+            pipeline.append({'$project': db.remap(projection)})
+
+        for entry in self._collection.aggregate(pipeline, allowDiskUse=True):
+            yield db.remap_back(entry)
+
+    def distinct(
+            self,
+            key: str,
+            filter: dict = None,  # pylint: disable=redefined-builtin
+    ) -> Iterator[dict]:
+        key = db.remap_key(key)
+        yield from self._collection.distinct(key, filter)
+
+    def get(self, entry_id: bson.ObjectId) -> dict:
+        doc = self._collection.find_one({'_id': entry_id})  # type: dict
+        if doc is None:
+            raise exceptions.NotFound(entry_id)
+        return db.remap_back(doc)
+
+    def count(
+            self,
+            filter: dict,  # pylint: disable=redefined-builtin
+            *,
+            meta: dict = None) -> int:
+        """Get the number of entries that match the search criteria"""
+        # Create the pipeline
+        pipeline = []
+
+        if filter:
+            pipeline.append({'$match': filter})
+
+        if meta:
+            pipeline.extend(
+                queries.pipeline_match_metadata(meta, self._meta_collection_name, db.OBJ_ID))
+
+        pipeline.append({'$count': 'total'})
+        try:
+            result = next(self._collection.aggregate(pipeline))
+        except StopIteration:
+            return 0
+        else:
+            return result['total']
+
+
 def connect(uri: str) -> MongoArchive:
     # URI Format is:
     # mongodb://[username:password@]host1[:port1][,...hostN[:portN]][/[database][?options]]
     parsed = pymongo.uri_parser.parse_uri(uri)
     if not parsed.get('database', None):
-        raise ValueError("Failed to supply database on MongoDB uri: {}".format(uri))
+        raise ValueError('Failed to supply database on MongoDB uri: {}'.format(uri))
 
     try:
         client = pymongo.MongoClient(uri)
