@@ -1,6 +1,7 @@
+# -*- coding: utf-8 -*-
 import functools
 
-from mincepy import q
+from .aggregation import and_, eq_
 from . import db
 
 
@@ -32,10 +33,10 @@ def pipeline_latest_version(data_collection: str) -> list:
                 'pipeline': [{
                     '$match': {
                         '$expr':
-                            q.and_(
+                            and_(
                                 # Match object id and version
-                                q.eq_(oid_var, '$$obj_id'),
-                                q.eq_(ver_var, '$$max_ver')),
+                                eq_(oid_var, '$$obj_id'),
+                                eq_(ver_var, '$$max_ver')),
                     }
                 }],
                 'as': 'latest'
@@ -70,7 +71,8 @@ def pipeline_match_metadata(meta: dict, meta_collection: str, local_field: str):
     })
     # _meta should only contain at most one entry per document i.e. the metadata for
     # that object.  So check that for the search criteria
-    pipeline.append({'$match': {'_meta.0.{}'.format(key): value for key, value in meta.items()}})
+    meta_filter = flatten_filter('_meta.0', meta)
+    pipeline.append({'$match': and_(*meta_filter)})
 
     return pipeline
 
