@@ -1,6 +1,7 @@
+# -*- coding: utf-8 -*-
 import itertools
 import logging
-from typing import Sequence, Union, Callable, Iterator, Iterable
+from typing import Sequence, Union, Callable, Iterator, Iterable, List
 
 import bson
 import networkx
@@ -9,6 +10,7 @@ import pymongo.collection
 import mincepy
 from mincepy import OUTGOING
 from mincepy import q
+from . import aggregation
 from . import db
 from . import types
 
@@ -73,7 +75,11 @@ class ReferenceManager:
 
         search_ids = self._prepare_for_ref_search(ids)
         pipeline = self._get_ref_pipeline(search_ids, direction=direction, max_dist=search_max_dist)
-        ref_results = {result['_id']: result for result in self._references.aggregate(pipeline)}
+        # Need to allow disk use as the graph can get huge
+        ref_results = {
+            result['_id']: result
+            for result in self._references.aggregate(pipeline, allowDiskUse=True)
+        }  # DB HIT
 
         graph = networkx.DiGraph()
 
@@ -92,6 +98,9 @@ class ReferenceManager:
 
                 # Then the edges
                 for entry in itertools.chain([result], refs):
+                    if 'refs' not in entry:
+                        continue
+
                     this = node_factory(entry['_id'])
 
                     for neighbour_id in entry['refs']:
@@ -103,11 +112,14 @@ class ReferenceManager:
         return graph
 
     def _get_ref_pipeline(self, ids: Sequence, direction=OUTGOING, max_dist: int = None) -> list:
-        """Get the reference lookup pipeline."""
+        """Get the reference lookup pipeline.  Given a sequence of ids, a direction and maximum distance this will
+        return a pipeline that can be used in an aggregation operation on the relevant collection to get the reference
+        graph."""
         if max_dist is not None and max_dist < 0:
             raise ValueError("max_dist must be positive, got '{}'".format(max_dist))
 
-        pipeline = [{'$match': {'_id': q.in_(*ids)}}]
+        # First match the IDs that we're interested in
+        pipeline = [{'$match': {'_id': aggregation.in_(*ids)}}]
 
         if max_dist is None or max_dist != 0:
             lookup_params = {
@@ -131,6 +143,7 @@ class ReferenceManager:
         return pipeline
 
     def _prepare_for_ref_search(self, ids: Sequence[Union[bson.ObjectId, mincepy.SnapshotId]]):
+        """Make sure that the references collections are up to date in preparation for a reference graph search"""
         hist_updated = False
         data_updated = False
         converted = []
@@ -153,7 +166,7 @@ class ReferenceManager:
 
         return converted
 
-    def _ensure_current(self, collection_name: str):
+    def _ensure_current(self, collection_name: str, ids=None):
         """This call ensures that the reference collection is up to date"""
         # Find all the objects that we don't have in the references collection
         if collection_name == 'history':
@@ -163,10 +176,10 @@ class ReferenceManager:
             collection = self._data_collection
             id_func = lambda schema_entry: schema_entry[1].obj_id
         else:
-            raise ValueError("Unsupported collection: {}".format(collection_name))
+            raise ValueError('Unsupported collection: {}'.format(collection_name))
 
         to_insert = []
-        for data_entry in self._get_missing_entries(collection):
+        for data_entry in self._get_missing_entries(collection, ids):
             ref_entry = _generate_ref_entry(data_entry, id_func)
             ref_entry['_id'] = data_entry['_id']
             to_insert.append(ref_entry)
@@ -177,9 +190,15 @@ class ReferenceManager:
                          collection_name, len(to_insert))
             self._references.insert_many(to_insert)
 
-    def _get_missing_entries(self, collection: pymongo.collection.Collection) -> Iterator:
+    def _get_missing_entries(self,
+                             collection: pymongo.collection.Collection,
+                             ids: List = None) -> Iterator:
         """Given a collection get the records that do not have entries in the references cache"""
-        pipeline = [{
+        pipeline = []
+        if ids is not None:
+            pipeline.append({'$match': {'_id': {'$in': ids}}})
+
+        pipeline.extend([{
             '$lookup': {
                 'from': self._references.name,
                 'localField': '_id',
@@ -190,8 +209,9 @@ class ReferenceManager:
             '$match': {
                 'references': []
             }
-        }]
-        yield from collection.aggregate(pipeline)
+        }])
+        # Need to allow disk use as the graph can get huge
+        yield from collection.aggregate(pipeline, allowDiskUse=True)
 
 
 def _generate_ref_entry(data_entry: dict, id_func: Callable) -> dict:
