@@ -1,7 +1,12 @@
+# -*- coding: utf-8 -*-
 """Classes and function useful for trying out mincepy functionality"""
+# pylint: disable=cyclic-import
+import contextlib
 import logging
 import os
+import string
 import random
+from typing import Iterator
 import uuid
 
 import bson
@@ -12,9 +17,47 @@ import mincepy
 logger = logging.getLogger(__name__)
 
 ENV_ARCHIVE_URI = 'MINCEPY_TEST_URI'
+ENV_ARCHIVE_BASE_URI = 'MINCEPY_TEST_BASE_URI'
 DEFAULT_ARCHIVE_URI = 'mongodb://localhost/mincepy-tests'
+DEFAULT_ARCHIVE_BASE_URI = 'mongodb://127.0.0.1'
+
+# pylint: disable=redefined-outer-name, invalid-name
+
+
+def get_base_uri() -> str:
+    """Get a base URI for an archive that can be used for testing.  This will not contain the database name as multiple
+    databases can be used during a test session."""
+    return os.environ.get(ENV_ARCHIVE_BASE_URI, DEFAULT_ARCHIVE_BASE_URI)
+
+
+def create_archive_uri(base_uri='', db_name=''):
+    """Get an archive URI based on the current archive base URI plus the passed database name.
+
+    If the database name is missing a random one will be used"""
+    if not db_name:
+        letters = string.ascii_lowercase
+        db_name = 'mincepy-' + ''.join(random.choice(letters) for _ in range(5))
+    base_uri = base_uri or get_base_uri()
+    return base_uri + '/' + db_name
+
+
+@contextlib.contextmanager
+def temporary_archive(archive_uri: str) -> Iterator[mincepy.Archive]:
+    """Create a temporary archive.  The associated database will be dropped on exiting the context"""
+    client = pymongo.MongoClient(archive_uri)
+    db = client.get_default_database()  # pylint: disable=invalid-name
+    client.drop_database(db)
+    mongo_archive = mincepy.mongo.MongoArchive(db)
+    yield mongo_archive
+    client.drop_database(db)
+
+
+@contextlib.contextmanager
+def temporary_historian(archive_uri: str = '') -> Iterator[mincepy.Archive]:
+    """Create a temporary historian.  The associated database will be dropped on exiting the context."""
+    with temporary_archive(archive_uri) as archive:
+        yield mincepy.Historian(archive)
 
-# pylint: disable=redefined-outer-name
 
 try:
     import pytest
@@ -22,17 +65,17 @@ try:
     # Optional pytest fixtures
 
     @pytest.fixture
-    def archive_uri():
+    def archive_uri() -> str:
         return os.environ.get(ENV_ARCHIVE_URI, DEFAULT_ARCHIVE_URI)
 
+    @pytest.fixture
+    def archive_base_uri() -> str:
+        return os.environ.get(ENV_ARCHIVE_BASE_URI, DEFAULT_ARCHIVE_BASE_URI)
+
     @pytest.fixture
     def mongodb_archive(archive_uri):
-        client = pymongo.MongoClient(archive_uri)
-        db = client.get_default_database()  # pylint: disable=invalid-name
-        client.drop_database(db)
-        mongo_archive = mincepy.mongo.MongoArchive(db)
-        yield mongo_archive
-        client.drop_database(db)
+        with temporary_archive(archive_uri) as mongo_archive:
+            yield mongo_archive
 
     @pytest.fixture(autouse=True)
     def historian(mongodb_archive):
@@ -46,19 +89,23 @@ except ImportError:
     logger.debug("pytest fixtures missing because pytest isn't installed")
 
 
-class Car(mincepy.SimpleSavable):
+class Car(mincepy.ConvenientSavable):
     TYPE_ID = bson.ObjectId('5e075d6244572f823ed93274')
-    ATTRS = 'colour', 'make'
+    colour = mincepy.field()
+    make = mincepy.field()
 
     def __init__(self, make='ferrari', colour='red'):
         super().__init__()
         self.make = make
         self.colour = colour
 
+    def __str__(self) -> str:
+        return '{} {}'.format(self.colour, self.make)
 
-class Garage(mincepy.SimpleSavable):
+
+class Garage(mincepy.ConvenientSavable):
     TYPE_ID = bson.ObjectId('5e07b40a44572f823ed9327b')
-    ATTRS = ('car',)
+    car = mincepy.field()
 
     def __init__(self, car=None):
         super().__init__()
@@ -69,9 +116,11 @@ class Garage(mincepy.SimpleSavable):
         return state
 
 
-class Person(mincepy.SimpleSavable):
+class Person(mincepy.ConvenientSavable):
     TYPE_ID = uuid.UUID('d60ca740-9fa6-4002-83f6-e4c91403e41b')
-    ATTRS = 'name', 'age', mincepy.AsRef('car')
+    name = mincepy.field()
+    age = mincepy.field()
+    car = mincepy.field(ref=True)
 
     def __init__(self, name, age, car=None):
         super().__init__()
@@ -80,9 +129,9 @@ class Person(mincepy.SimpleSavable):
         self.car = car
 
 
-class Cycle(mincepy.SimpleSavable):
+class Cycle(mincepy.ConvenientSavable):
     TYPE_ID = uuid.UUID('600fb6ae-684c-4f8e-bed3-47ae06739d29')
-    ATTRS = ('_ref',)
+    _ref = mincepy.field()
 
     def __init__(self, ref=None):
         super().__init__()
@@ -131,7 +180,7 @@ def populate(historian=None):
         car.save()
 
     people = mincepy.RefList()
-    for name in ('martin', 'sonia', 'gavin', 'upul', 'sebastiaan', 'irene'):
+    for name in ('martin', 'sonia', 'gavin', 'upul', 'martin', 'sebastiaan', 'irene'):
         person = Person(name, random.randint(20, 40))
         historian.save(person)
         people.append(person)
