@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 from abc import ABCMeta, abstractmethod
 import datetime
 from typing import Type, List
@@ -10,6 +11,9 @@ except ImportError:  # Python < 3.6
 
 import mincepy  # pylint: disable=unused-import
 from . import depositors
+from . import expr
+from . import fields
+from . import saving
 from . import tracking
 
 __all__ = 'Savable', 'Comparable', 'Object', 'SavableObject', 'PRIMITIVE_TYPES'
@@ -20,24 +24,35 @@ PRIMITIVE_TYPES = (bool, int, float, str, dict, list, type(None), bytes, uuid.UU
 
 
 def is_primitive(obj):
-    return isinstance(obj, PRIMITIVE_TYPES)
+    return obj.__class__ in PRIMITIVE_TYPES
 
 
-class Savable(metaclass=ABCMeta):
+class Savable(fields.WithFields, expr.FilterLike):
     """Interface for an object that can save an load its instance state"""
     TYPE_ID = None
     LATEST_MIGRATION = None  # type: mincepy.ObjectMigration
 
-    def __init__(self):
-        assert self.TYPE_ID is not None, "Must set the TYPE_ID for an object to be savable"
+    def __init__(self, *args, **kwargs):
+        assert self.TYPE_ID is not None, 'Must set the TYPE_ID for an object to be savable'
+        super().__init__(*args, **kwargs)
 
-    @abstractmethod
-    def save_instance_state(self, saver: depositors.Saver):
+    @classmethod
+    def __expr__(cls):
+        """This method gives savables the ability to be used as an expression"""
+        return expr.Comparison('type_id', expr.Eq(cls.TYPE_ID))
+
+    @classmethod
+    def __query_expr__(cls) -> dict:
+        """This method gives savables the ability to be used in query filter expressions"""
+        return cls.__expr__().__query_expr__()
+
+    def save_instance_state(self, saver: depositors.Saver):  # pylint: disable=unused-argument
         """Save the instance state of an object, should return a saved instance"""
+        return saving.save_instance_state(self)
 
-    @abstractmethod
-    def load_instance_state(self, saved_state, loader: depositors.Loader):
+    def load_instance_state(self, saved_state, loader: depositors.Loader):  # pylint: disable=unused-argument
         """Take the given object and load the instance state into it"""
+        saving.load_instance_state(self, saved_state)
 
 
 class Comparable(metaclass=ABCMeta):
@@ -52,19 +67,36 @@ class Comparable(metaclass=ABCMeta):
         """Produce a hash representing the value"""
 
 
-class Object(Comparable, metaclass=ABCMeta):  # pylint: disable=abstract-method
+class Object(Comparable, metaclass=ABCMeta):
     """A simple object that is comparable"""
 
 
-class SavableObject(Object, Savable, metaclass=ABCMeta):  # pylint: disable=abstract-method
+class SavableObject(Object, Savable, metaclass=ABCMeta):
     """A class that is both savable and comparable"""
 
     _historian = None
 
-    def __init__(self):
-        super().__init__()
+    @classmethod
+    def init_field(cls, field: fields.Field, attr_name: str):
+        super().init_field(field, attr_name)
+        field.set_query_context(expr.Comparison('type_id', expr.Eq(cls.TYPE_ID)))
+        field.path_prefix = 'state'
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
         tracking.obj_created(self)
 
+    def __eq__(self, other) -> bool:
+        """Determine if two objects are equal"""
+        if not isinstance(other, type(self)):
+            return False
+
+        return saving.save_instance_state(self) == saving.save_instance_state(other)
+
+    def yield_hashables(self, hasher):
+        """Produce a hash representing the object"""
+        yield from hasher.yield_hashables(saving.save_instance_state(self))
+
 
 class Equator:
 
@@ -87,8 +119,8 @@ class Equator:
         self._equators.reverse()
         try:
             self._equators.remove(equator)
-        except ValueError:
-            raise ValueError("Unknown equator '{}'".format(equator))
+        except ValueError as exc:
+            raise ValueError("Unknown equator '{}'".format(equator)) from exc
         finally:
             self._equators.reverse()
 
@@ -108,8 +140,8 @@ class Equator:
             try:
                 yield from obj.yield_hashables(self)
             except AttributeError:
-                raise TypeError("No helper registered and no yield_hashabled method on '{}'".format(
-                    type(obj)))
+                raise TypeError("No helper registered and no yield_hashables method on '{}'".format(
+                    type(obj))) from None
         else:
             yield from equator.yield_hashables(obj, self)
 
