@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 import pytest
 
 import mincepy
@@ -15,9 +16,17 @@ def test_delete(historian: mincepy.Historian):
         historian.load(car_id)
 
     records = historian.history(car_id, as_objects=False)
-    assert len(records) == 2, "There should be two record, the initial and the delete"
+    assert len(records) == 2, 'There should be two record, the initial and the delete'
     assert records[-1].is_deleted_record()
 
+    # Check imperative deleting
+    with pytest.raises(mincepy.NotFound):
+        historian.delete(car_id)
+    # This, should not raise:
+    result = historian.delete(car_id, imperative=False)
+    assert not result.deleted
+    assert car_id in result.not_found
+
 
 def test_delete_from_obj_id(historian: mincepy.Historian):
     """Test deleting an object using it's object id"""
@@ -67,11 +76,11 @@ def test_delete_find(historian: mincepy.Historian):
     car_id = car.save()
 
     historian.delete(car_id)
-    assert len(tuple(historian.find(obj_id=car_id))) == 0
+    assert historian.find(obj_id=car_id).count() == 0
 
     # Now check the archive
-    assert len(tuple(historian.archive.find(obj_id=car_id))) == 2
-    assert len(tuple(historian.archive.find(obj_id=car_id, state=mincepy.DELETED))) == 1
+    assert historian.snapshots.records.find(obj_id=car_id).count() == 2
+    assert historian.snapshots.records.find(obj_id=car_id, state=mincepy.DELETED).count() == 1
 
 
 def test_delete_multiple_versions(historian: mincepy.Historian):
