@@ -11,9 +11,9 @@ from mincepy.testing import Car, Person
 def test_path_helper(historian: mincepy.Historian):
     historian.register_type(mincepy.common_helpers.PathHelper())
 
-    class File(mincepy.SimpleSavable):
+    class File(mincepy.ConvenientSavable):
         TYPE_ID = uuid.UUID('8d645bb8-4657-455b-8b61-8613bc8a0acf')
-        ATTRS = ('path',)
+        path = mincepy.field()
 
         def __init__(self, path):
             super(File, self).__init__()
